@@ -1,7 +1,10 @@
 use log::debug;
+use serde::Serialize;
 use serde_json::Value;
 use std::process::Command;
+
 /// A CLI wrapper object
+#[derive(Debug, Serialize)]
 pub struct Cli {
     /// The bin_path to find the crio_cli required as the host process may not have this preconfigured.
     /// Usually set to "/bin:/sbin:/usr/bin:/usr/sbin:/usr/local/bin:/home/kubernetes/bin"
@@ -14,7 +17,7 @@ pub struct Cli {
 }
 
 /// A switch to indicate which image command to run
-#[derive(Debug)]
+#[derive(Debug, Serialize)]
 pub enum ImageCommand {
     Img,
     Image,
@@ -200,7 +203,7 @@ impl Cli {
         }
     }
 
-    /// Returns a JSON value containing the images related to a container
+    /// Returns a text value containing the logs related to a container
     ///
     /// # Arguments
     ///
@@ -215,8 +218,10 @@ impl Cli {
     ///     bin_path,
     ///     ..Default::default()
     /// };
+    /// #[allow(deprecated)]
     /// let val = cli.logs("sha256:3b8adc6c30f4e7e4afb57daef9d1c8af783a4a647a4670780e9df085c0525efa").unwrap();
     /// ```
+    #[deprecated]
     pub fn logs(&self, container_id: &str) -> Result<String, String> {
         let log_output_args = match &self.config_path {
             Some(s) => vec!["-c", s.as_str(), "logs", container_id],
@@ -225,6 +230,34 @@ impl Cli {
         run_command_text(log_output_args, &self.bin_path)
     }
 
+    /// Returns a text value containing the logs related to a container
+    ///
+    /// # Arguments
+    ///
+    /// * `container_id` - The container_id related to one of the containers obtained from `pod_containers`
+    ///
+    /// * `line_count` - The number of lines to take from the end of the log.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use libcrio::Cli;
+    /// let bin_path = format!("{}/mock/iks", env!("CARGO_MANIFEST_DIR"));
+    /// let cli = Cli {
+    ///     bin_path,
+    ///     ..Default::default()
+    /// };
+    /// let val = cli.tail_logs("sha256:3b8adc6c30f4e7e4afb57daef9d1c8af783a4a647a4670780e9df085c0525efa", 500).unwrap();
+    /// ```
+    pub fn tail_logs(&self, container_id: &str, line_count: u32) -> Result<String, String> {
+        let tailoption = format!("--tail={}", line_count);
+        let log_output_args = match &self.config_path {
+            Some(s) => vec!["-c", s.as_str(), "logs", tailoption.as_str(), container_id],
+            None => vec!["logs", tailoption.as_str(), container_id],
+        };
+        run_command_text(log_output_args, &self.bin_path)
+    }
+
     /// # Arguments
     ///
     /// * `path` - The additional path to append to bin_path,
@@ -349,6 +382,15 @@ mod tests {
         }
     }
 
+    pub fn get_long_logs_cli() -> Cli {
+        let bin_path = format!("{}/mock/long_logs:/usr/bin", env!("CARGO_MANIFEST_DIR"));
+        Cli {
+            bin_path,
+            config_path: None,
+            image_command: ImageCommand::Img,
+        }
+    }
+
     pub fn get_mixed_errors_cli() -> Cli {
         let bin_path = format!("{}/mock/mixed_errors", env!("CARGO_MANIFEST_DIR"));
         Cli {
@@ -599,6 +641,7 @@ mod tests {
     /*************************************************************************
      * log tests
      **************************************************************************/
+    #[allow(deprecated)]
     #[test]
     fn test_logs() {
         for cli in get_clis() {
@@ -608,6 +651,7 @@ mod tests {
             assert_eq!(val, "A LOG\n".to_string())
         }
     }
+    #[allow(deprecated)]
     #[test]
     fn test_logs_only_errors_cli() {
         let cli = get_only_errors_cli();
@@ -615,6 +659,7 @@ mod tests {
         let expected = Err(String::from("failed to execute crictl [\"logs\", \"51cd8bdaa13a65518e790d307359d33f9288fc82664879c609029b1a83862db6\"] "));
         assert_eq!(expected, val);
     }
+    #[allow(deprecated)]
     #[test]
     fn test_logs_mixed_errors_cli() {
         let cli = get_mixed_errors_cli();
@@ -624,4 +669,17 @@ mod tests {
          ));
         assert_eq!(expected, val);
     }
+    #[test]
+    fn test_tail_logs() {
+        let cli = get_long_logs_cli();
+        let val = cli
+            .tail_logs(
+                "51cd8bdaa13a65518e790d307359d33f9288fc82664879c609029b1a83862db6",
+                500,
+            )
+            .unwrap();
+        assert_eq!(val.lines().count(), 500);
+        assert!(val.ends_with("logging 500\n"));
+        assert!(!val.contains("logging 501"));
+    }
 }
